# EgressGateway

The Egress Gateway configures a connector to act as a gateway to the Internet, typically for other connectors. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**local_binds** | [**[AgentConnectorLocalBind]**](AgentConnectorLocalBind.md) | A list describing the local proxy binds for egress gateway requests.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


